##  Updating the Linked Item to the Latest Version for a Single Fact Sheet
Follow these steps:
  1. On the right-side pane of the business capability fact sheet, under Reference Catalog, click Linked.
  2. On the reference catalog page, click Review and Update, review the changes, then confirm your action.
